BitSet

Struct BitSet 

pub struct BitSet<const N: usize>(/* private fields */);
Array based bitset implementation. N gives the size in Bytes of the bucket

Implementations

Source

impl<const N: usize> BitSet<N>

pub const fn new() -> Self

Creates a new bitset

pub fn set_nth_bit(&mut self, index: usize) -> bool

Set the value of the nth bit (set to 1)

Panics

Panic on index out of bound

pub fn unset_nth_bit(&mut self, index: usize) -> bool

Unset the value of the nth bit (set to 0)

Panics

Panic on index out of bound

pub fn get_nth_bit(&self, index: usize) -> bool

Get the value of the nth bit

Panics

Panic on index out of bound

pub fn as_slice(&self) -> &[u8]

pub fn as_mut_slice(&mut self) -> &mut [u8]

pub fn clear(&mut self)

Clears out a bitset (set all the bits to 0)

pub const fn bit_len(&self) -> usize

Returns the size in bits of the bitset

pub const fn byte_len(&self) -> usize

Returns the size in bytes of the bitset

pub fn count_ones(&self) -> usize

Counts bits to one in the current set

pub fn union(&mut self, other: &Self)

Make the union of the current set with another one

pub fn intersection(&mut self, other: &Self)

Make the intersection of the current set with another one

pub const fn count_ones_in_common(&self, other: &Self) -> usize

Count bits to one in common between two sets

pub fn count_zeros(&self) -> usize

Counts bits to zero in the current set

pub const fn byte_size() -> usize

Returns the size in bytes of the bitset

pub const fn bit_size() -> usize

Returns the size in bytes of the bitset