pub struct BitSet<const N: usize>(/* private fields */);Expand description
Array based bitset implementation. N gives the size in Bytes of the bucket
Implementations
Sourceimpl<const N: usize> BitSet<N>
impl<const N: usize> BitSet<N>
Sourcepub fn set_nth_bit(&mut self, index: usize) -> bool
pub fn set_nth_bit(&mut self, index: usize) -> bool
Sourcepub fn unset_nth_bit(&mut self, index: usize) -> bool
pub fn unset_nth_bit(&mut self, index: usize) -> bool
Sourcepub fn get_nth_bit(&self, index: usize) -> bool
pub fn get_nth_bit(&self, index: usize) -> bool
pub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_mut_slice(&mut self) -> &mut [u8] ⓘ
Sourcepub fn count_ones(&self) -> usize
pub fn count_ones(&self) -> usize
Counts bits to one in the current set
Sourcepub fn intersection(&mut self, other: &Self)
pub fn intersection(&mut self, other: &Self)
Make the intersection of the current set with another one
Sourcepub const fn count_ones_in_common(&self, other: &Self) -> usize
pub const fn count_ones_in_common(&self, other: &Self) -> usize
Count bits to one in common between two sets
Sourcepub fn count_zeros(&self) -> usize
pub fn count_zeros(&self) -> usize
Counts bits to zero in the current set